

# QtFind
![QtFind Logo](https://github.com/amad3v/QtFind/raw/master/qtfind/Icon.png)

graphical interface for the powerful command find

- [Installation](#installation)
- [Description](#description)
- [License](#license)
- [Features](#features)
- [Report a bug](#report-a-bug)
- [Screenshots](#screenshots)

## **Installation**

    pip install qtfind

## **Description**

:mag: **QtFind** is a graphical interface for the powerful command ***find***.

:mag: **QtFind** is designed with new comers to linux in mind.

:mag: **QtFind** also reveals the full command of the selected combination.

:mag: **QtFind** is made with PyQt5

***from the man page***

*GNU find searches the directory tree rooted at each given file name by evaluating the given expression from left to right, according to the rules of precedence.*

## **License**
This program comes with absolutely no warranty.
See the [GNU General Public Licence](https://www.gnu.org/licenses/gpl-3.0.html), version 3 or later for details.

## **Features**
 - Default and dark (4 tones) themes
 - Show/Copy constructed command
 - Interrupt search
 - Most of find options available (refer to `man find` for more information)

## **Report a bug**
[https://github.com/amad3v/QtFind/issues](https://github.com/amad3v/QtFind/issues)

## **Screenshots**

*Dark theme (tone: green):*

![dark theme](https://github.com/amad3v/QtFind/raw/master/docs/dark.png)

*Default theme:*

![default theme](https://github.com/amad3v/QtFind/raw/master/docs/light.png)

Copyright :copyright: 2019 - amad3v
